### Code
- `data_prep.py` will save 3 files, 2 for the aggregated time series data (in csv and parquet format) and one for the summed confirms, deaths and recoveries by day for trendlining. 
- When the script is run, the files will be saved to a datafolder titled with the current date of extraction.